==> jtreg_4.1-b09.orig.tar.gz: jtreg-jtreg4.1-b09/src/share/classes/com/sun/javatest/regtest/CachingTestFilter.java <==
/*
 * Copyright (c) 2011, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.sun.javatest.regtest;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

import com.sun.javatest.TestDescription;
import com.sun.javatest.TestFilter;

/**
 * A test filter that caches the results of a delegate filter.
 */
public class CachingTestFilter extends TestFilter {
    private TestFilter delegate;
    private Map<TestDescription, Boolean> cache = new HashMap<TestDescription, Boolean>();

    CachingTestFilter(TestFilter delegate) {
        if (delegate == null)
            throw new NullPointerException();
        this.delegate = delegate;
    }

    Map<TestDescription, Boolean> getCache() {
        return Collections.unmodifiableMap(cache);
    }

    @Override
    public String getName() {
        return delegate.getName();
    }

    @Override
    public String getDescription() {
        return delegate.getDescription();
    }

    @Override
    public String getReason() {
        return delegate.getReason();
    }

    @Override
    public boolean accepts(TestDescription td) throws Fault {
        Boolean b = cache.get(td);
        if (b == null)
            cache.put(td, b = delegate.accepts(td));
        return b;
    }
}

==> jtreg_4.2-b01.orig.tar.gz: jtreg-jtreg4.2-b01/src/share/classes/com/sun/javatest/regtest/CachingTestFilter.java <==
/*
 * Copyright (c) 2011, 2014, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.sun.javatest.regtest;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

import com.sun.javatest.TestDescription;
import com.sun.javatest.TestFilter;

/**
 * A test filter that caches the results of a delegate filter.
 */
public class CachingTestFilter extends TestFilter {
    private TestFilter delegate;
    private final Map<TestDescription, Boolean> cache = new HashMap<TestDescription, Boolean>();

    CachingTestFilter(TestFilter delegate) {
        if (delegate == null)
            throw new NullPointerException();
        this.delegate = delegate;
    }

    Map<TestDescription, Boolean> getCache() {
        return Collections.unmodifiableMap(cache);
    }

    @Override
    public String getName() {
        return delegate.getName();
    }

    @Override
    public String getDescription() {
        return delegate.getDescription();
    }

    @Override
    public String getReason() {
        return delegate.getReason();
    }

    @Override
    public boolean accepts(TestDescription td) throws Fault {
        Boolean b = cache.get(td);
        if (b == null)
            cache.put(td, b = delegate.accepts(td));
        return b;
    }
}
